Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromAuthHeader ¶
FromAuthHeader is a "TokenExtractor" that takes a give request and extracts the JWT token from the Authorization header.
Types ¶
type Adapter ¶
func CORSHandler ¶
func CORSHandler() Adapter
CORSHandler allows http to be served adding necessary headers to response
func JwtHandler ¶
func JwtHandler() Adapter
Click to show internal directories.
Click to hide internal directories.